
    /* Custom animation for title */
    @keyframes fadeInScale {
        0% {
          opacity: 0;
          transform: scale(0.5);
        }
        100% {
          opacity: 1;
          transform: scale(1);
        }
      }
      .animate-fadeInScale {
        animation: fadeInScale 1s ease-out;
        animation-delay: 0s;
        animation-fill-mode: forwards;
    }