{% extends "base.html" %}

{% block title %}Visualseek - APISEEK{% endblock %}

{% block header %}VISUALSEEK{% endblock %}

{% block content %}
  <div class="text-center">
    <p class="text-xl">Welcome to Visualseek.</p>
    <p class="mt-4 text-gray-400">This page is under construction. Stay tuned for upcoming features!</p>
  </div>
{% endblock %}
